@@ -54,7 +54,7 @@ def __str_representable__(dict):
 			else:
 				s += i[:-1]+"\n"
 		c += 1
-	return s[:-1].replace(" : \n",":\n")
+	return s[:-1].replace(": : \n"," :\n").replace(" : \n",":\n")
 
 # a default cli object
 class CLI(object):
@@ -66,28 +66,47 @@ class CLI(object):
 		self.options = options
 		self.notes = notes
 		self.author = author
-		self.documentation = self.__create_docs__()
+		self.executable = executable
+		self.arguments = self.Arguments(executable=self.executable, docs=self.docs, stop=self.stop)
+		self.arguments.documentation = self.documentation = self.__create_docs__()
 
 		#
-	def argument_present(self, argument):
-		return argument_present(argument)
-	def arguments_present(self, arguments):
-		return arguments_present(arguments)
-	def get_argument(self, argument, required=True, index=1, empty=None):
-		return get_argument(argument, required=required, index=index,empty=empty)
-	def check_arguments(self, json=False):
-		lexecutable = self.executable
-		while True:
-			if len(lexecutable) > 0 and lexecutable[len(lexecutable)-1] == "/": lexecutable = lexecutable[:-1]
-			else: break
-		for i in sys.argv:
-			if i not in ["", lexecutable]:
-				if f" {i}: " not in self.modes_str and f" {i}: " not in self.options_str:
-					error = f"Argument [{i}] is not a valid mode nor option."
-					if json:
-						response.log(error=error, json=True)
-						sys.exit(1)
-					else: raise UnkownArgumentError(error)
+	class Arguments(object):
+		def __init__(self, executable=None, docs=None, stop=None,):
+			self.docs = docs
+			self.stop = stop
+			self.executable = executable
+		def present(self, argument):
+			if isinstance(argument, str):
+				return argument_present(argument)
+			else:
+				return arguments_present(argument)
+		def get(self, argument, required=True, index=1, empty=None):
+			if isinstance(argument, str):
+				return get_argument(argument, required=required, index=index,empty=empty)
+			else:
+				arguments = []
+				for i in argument: 
+					arguments.append(get_argument(i, required=required, index=index,empty=empty))
+				return arguments	
+		def check(self, json=False):
+			lexecutable = self.executable
+			while True:
+				if len(lexecutable) > 0 and lexecutable[len(lexecutable)-1] == "/": lexecutable = lexecutable[:-1]
+				elif "//" in lexecutable: lexecutable = lexecutable.replace("//","/")
+				else: break
+			for i in sys.argv:
+				if i not in ["", lexecutable] and not os.path.exists(i) and (len(i) < 1 or (i[0] == "-")):
+					if f" {i}: " not in self.modes_str and f" {i}: " not in self.options_str and f" {i} " not in self.modes_str and f" {i} " not in self.options_str:
+						error = f"Argument [{i}] is not a valid mode nor option."
+						if json:
+							response.log(error=error, json=True)
+							sys.exit(1)
+						else: 
+							self.docs(stop=False)
+							sys.tracebacklimit = -1
+							sys.traceback_limit = -1
+							raise UnkownArgumentError(error)
 	def stop(self,
 		# success exit.
 		success=True,
@@ -157,13 +176,14 @@ class CLI(object):
 							if not(len(l) > 0 and len[0] == "-"):
 								include = False
 					if include: new += line+"\n"
-				if mode != None and f" {mode}: " in new:
-					s = new.split(f" {mode}: ")
-					before = s[0]+f" {mode}: "
+				if mode != None and (f" {mode}: " in new or f" {mode} " in new):
+					id = Formats.String(line).first_occurence(charset=[f" {mode} ", f" {mode}: "])
+					s = new.split(id)
+					before = s[0]+id
 					_new_, include, indent = "", False, None
 					for line in new.split("\n"):
-						if f" {mode}: " in new:
-							indent = len(line.split(f"{mode}:")[0])
+						if id in new:
+							indent = len(line.split(id)[0])
 							include = True
 						elif indent != None and ":" in line:
 							l = line[indent:].split(":")[0]
@@ -173,13 +193,14 @@ class CLI(object):
 					docs = before + _new_ + after
 				else:
 					docs = before + new + after
-			elif mode != None:
-				s = docs.split(f" {mode}: ")
-				before = s[0]+f" {mode}: "
+			if mode != None and (f" {mode}: " in new or f" {mode} " in new):
+				id = Formats.String(line).first_occurence(charset=[f" {mode} ", f" {mode}: "])
+				s = docs.split(id)
+				before = s[0]+id
 				_new_, include, indent = "", False, None
 				for line in docs.split("\n"):
-					if f" {mode}: " in docs:
-						indent = len(line.split(f"{mode}:")[0])
+					if id in docs:
+						indent = len(line.split(id)[0])
 						include = True
 					elif indent != None and ":" in line:
 						l = line[indent:].split(":")[0]
@@ -205,8 +226,8 @@ class CLI(object):
 		#
 	# system functions.
 	def __create_docs__(self):
-		self.modes_str = m = __str_representable__(self.modes)
-		self.options_str = o = __str_representable__(self.options)
+		self.modes_str  = self.arguments.modes_str = m = __str_representable__(self.modes)
+		self.options_str = self.arguments.options_str = o = __str_representable__(self.options)
 		n = __str_representable__(self.notes)
 		c = f"\nAuthor: {self.author}. \nCopyright: © {self.author} {datetime.datetime.today().strftime('%Y')}. All rights reserved."
 		doc = "Usage: "+self.alias+" <mode> <options> \nModes:\n"+m
